@@ -1,4 +1,3 @@
-context("createDummyFeatures")
 
 test_that("createDummyFeatures", {
   df = data.frame(a = 1:5, b = letters[1:5], c = LETTERS[c(1, 1, 1, 2, 2)], stringsAsFactors = FALSE)
@@ -16,9 +15,12 @@ test_that("createDummyFeatures", {
   expect_equal(colnames(df.bc), c("a", "b.a", "b.b", "b.c", "b.d", "b.e", "c.A", "c.B"))
 
   grid = createDummyFeatures(expand.grid(x1 = letters[1:2], x2 = letters[3:4]), method = "reference")
-  expect_equal(colnames(grid), c("x1.b", "x2.d"))
+  expect_equal(colnames(grid), c("x1.b", "x2.d"), ignore_attr = "env")
 
   dummy.task = createDummyFeatures(iris.task)
+  # comparing the env slot will lead to failures
+  dummy.task$env = NULL
+  iris.task$env = NULL
   expect_equal(dummy.task, iris.task)
 
   df$a = as.factor(df$a)
