@@ -1,4 +1,3 @@
-context("regr_xgboost")
 
 test_that("regr_xgboost", {
   requirePackagesOrSkip("xgboost", default.method = "load")
@@ -14,14 +13,14 @@ test_that("regr_xgboost", {
     parset = parset.list[[i]]
     if (is.null(parset$verbose)) parset$verbose = 0L
     if (is.null(parset$nrounds)) parset$nrounds = 1L
-    if (is.null(parset$objective)) parset$objective = "reg:linear"
+    if (is.null(parset$objective)) parset$objective = "reg:squarederror"
     pars = list(data = data.matrix(regr.num.train[, -regr.num.class.col]),
       label = as.numeric(regr.num.train[, regr.num.class.col]))
     pars = c(pars, parset)
     model = do.call(xgboost::xgboost, pars)
     # model = xgboost::xgboost(data = data.matrix(regr.num.train[,-regr.num.class.col]), verbose = 0L,
     # label = as.numeric(regr.num.train[,regr.num.class.col]),
-    # nrounds = 20, objective = "reg:linear", missing = NULL)
+    # nrounds = 20, objective = "reg:squarederror", missing = NULL)
     old.predicts.list[[i]] = predict(model,
       data.matrix(regr.num.test[, -regr.num.class.col]))
   }
